==> xpx_chain_sdk-0.0.3%2B5.tar.gz: CHANGELOG.md <==
## 0.0.3+5

### New Features
[ADD] ModifyMultisigAccountTransaction support.

[ADD] Get ModifyMultisigInfo.

[ADD] LockFunds support.

[ADD] Get LockFundsTransactionInfo.

[ADD] Getter publicKey and address from Account class.

[ADD] Get aggregateBondedTransactions.

[ADD] AnnounceAggregateBonded and AnnounceAggregateBondedCosignature.

[ADD] CosignatureTransaction class.

### Updates
[UPDATE] Reformat style.

[UPDATE] Update example.

[UPDATE] refactor AggregateTransaction class.

[UPDATE] rename AccountPropertyDTO to _AccountPropertyDTO.

[UPDATE] xpx_crypto to 0.0.2+2.

### Fixed bugs

[UPDATE] fixed bug in TableArrayAttribute.

## 0.0.3+4

### Updates
[UPDATE] latest published versions for http dependency.

## 0.0.3+3

### Updates
[UPDATE] Reformat style.

[UPDATE] Update example.


### Fixed bugs
[FIXED] fixed bug in Deadline null

[FIXED] fixed bug in MosaicSupplyChangeTransaction

[FIXED] fixed bug in duration MosaicDefinition

[FIXED] fixed bug in duration namespace

[FIXED] fixed bug in _MessageDTO null

[FIXED] fixed bug in parentId null

[FIXED] fixed bug in List _MosaicNameDTO

[FIXED] fixed bug in List _MosaicInfoDTO

[FIXED] fixed bug in List _BlockInfoDTO

[FIXED] fixed bug in BlockInfoDTO

## 0.0.3+2

### Updates
[UPDATE] Reformat style.

[UPDATE] rename Config Class.

[UPDATE] refactor Client Class to ApiClient.

[UPDATE] examples.


## 0.0.3+1

- Initial version, created by Eleazar Garrido.

### New Features
[ADD] Get Account MultiSig Info.

[ADD] Get Account MultiSign Graph Info.

[ADD] Get Transaction Status.

[ADD] Get Transactions Statuses.

### Updates
[UPDATE] Documentation fixes.

[UPDATE] Reformat style.

[UPDATE] dependencies.

[UPDATE] examples.

### Fixed bugs
[FIXED] Undefined name 'HEX'.

[DELETED] removed unused functions.

==> xpx_chain_sdk-0.0.7%2B5.tar.gz: CHANGELOG.md <==
## 0.0.7+5
### Updates
[UPDATE] update README

## 0.0.7+4
### New Features
[ADD] Metadata version V2 support.

## 0.0.7+2
### New Features
[ADD] Transaction examples api.

## 0.0.7+1
### Updates
[UPDATE] sdk: '>=2.16.0'.

## 0.0.6+6
### Updates
[UPDATE] Homepage URL.

## 0.0.6+5
### New Features
[ADD] Message encrypted.

### Updates
[UPDATE] format code.

## 0.0.5+5
[ADD] Message toJson method.

## 0.0.5+4
### Updates
[UPDATE] analysis code.

## 0.0.5+3
### Updates
[UPDATE] format code.

## 0.0.5+2
### New Features
[ADD] AccountPropertiesAddressTransaction.

[ADD] AccountPropertiesMosaicTransaction.

[ADD] AccountPropertiesEntityTypeTransaction.

## 0.0.5+1
### New Features
[ADD] AddExchangeOfferTransaction model.

[ADD] Extension AliasTypeToInt and AliasActionTypeToInt.

[ADD] ExchangeOfferTransaction class.

[ADD] RemoveExchangeOfferTransaction class.

[ADD] RemoveExchangeOfferTransaction class.

[ADD] ExchangeRoutes Api.

### Updates
[UPDATE] BigInt method.

[UPDATE] Buffer Endian.

[UPDATE] Unnecessary new keyword.

## 0.0.4+1
### New Features
[UPDATE] Update Sirius chain 0.5.0

## 0.0.3+5
### New Features
[ADD] ModifyMultisigAccountTransaction support.

[ADD] Get ModifyMultisigInfo.

[ADD] LockFunds support.

[ADD] Get LockFundsTransactionInfo.

[ADD] Getter publicKey and address from Account class.

[ADD] Get aggregateBondedTransactions.

[ADD] AnnounceAggregateBonded and AnnounceAggregateBondedCosignature.

[ADD] CosignatureTransaction class.

### Updates
[UPDATE] Reformat style.

[UPDATE] Update example.

[UPDATE] refactor AggregateTransaction class.

[UPDATE] rename AccountPropertyDTO to AccountPropertyDTO.

[UPDATE] xpx_crypto to 0.0.2+2.

### Fixed bugs

[UPDATE] fixed bug in TableArrayAttribute.

## 0.0.3+4
### Updates
[UPDATE] latest published versions for http dependency.

## 0.0.3+3
### Updates
[UPDATE] Reformat style.

[UPDATE] Update example.

### Fixed bugs
[FIXED] fixed bug in Deadline null

[FIXED] fixed bug in MosaicSupplyChangeTransaction

[FIXED] fixed bug in duration MosaicDefinition

[FIXED] fixed bug in duration namespace

[FIXED] fixed bug in MessageDTO null

[FIXED] fixed bug in parentId null

[FIXED] fixed bug in List MosaicNameDTO

[FIXED] fixed bug in List MosaicInfoDTO

[FIXED] fixed bug in List BlockInfoDTO

[FIXED] fixed bug in BlockInfoDTO

## 0.0.3+2
### Updates
[UPDATE] Reformat style.

[UPDATE] rename Config Class.

[UPDATE] refactor Client Class to ApiClient.

[UPDATE] examples.

## 0.0.3+1
- Initial version, created by Eleazar Garrido.

### New Features
[ADD] Get Account MultiSig Info.

[ADD] Get Account MultiSign Graph Info.

[ADD] Get Transaction Status.

[ADD] Get Transactions Statuses.

### Updates
[UPDATE] Documentation fixes.

[UPDATE] Reformat style.

[UPDATE] dependencies.

[UPDATE] examples.

### Fixed bugs
[FIXED] Undefined name 'HEX'.

[DELETED] removed unused functions.
